@@ -1,6 +1,6 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include <QCoreApplication>
 #include <QFile>
 #include <QReadLocker>
-#include <QRegExp>
+#include <QRegularExpression>
 #include <QThread>
 #include <QWriteLocker>
 #include <drumstick/alsaclient.h>
@@ -1946,7 +1946,7 @@ ClientInfo::getErrorBounce()
 /**
  * Gets the client's event filter.
  * @return The client's event filter.
- * @deprecated
+ * @deprecated Use isFiltered() instead.
  */
 const unsigned char*
 ClientInfo::getEventFilter()
@@ -2017,7 +2017,7 @@ ClientInfo::setErrorBounce(bool val)
 /**
  * Sets the event filter.
  * @param filter The event filter.
- * @deprecated
+ * @deprecated Use addFilter() instead.
  */
 void
 ClientInfo::setEventFilter(unsigned char *filter)
@@ -2442,17 +2442,18 @@ getRuntimeALSALibraryVersion()
 int
 getRuntimeALSALibraryNumber()
 {
-    QRegExp rx("(\\d+)");
+    QRegularExpression rx("(\\d+)");
     QString str = getRuntimeALSALibraryVersion();
     bool ok;
-    int pos = 0, result = 0, j = 0;
-    while ((pos = rx.indexIn(str, pos)) != -1 && j < 3) {
-        int v = rx.cap(1).toInt(&ok);
+    int result = 0, j = 0;
+    QRegularExpressionMatchIterator i = rx.globalMatch(str);
+    while (i.hasNext() && (j < 3)) {
+        QRegularExpressionMatch m = i.next();
+        int v = m.captured(1).toInt(&ok);
         if (ok) {
             result <<= 8;
             result += v;
         }
-        pos += rx.matchedLength();
         j++;
     }
     return result;
@@ -2467,13 +2468,16 @@ getRuntimeALSALibraryNumber()
 QString
 getRuntimeALSADriverVersion()
 {
-    QRegExp rx(".*Driver Version.*([\\d\\.]+).*");
+    QRegularExpression rx("([\\d\\.]+)");
     QString s;
     QFile f("/proc/asound/version");
     if (f.open(QFile::ReadOnly)) {
         QTextStream str(&f);
-        if (rx.exactMatch(str.readLine().trimmed()))
-            s = rx.cap(1);
+        QString sub = str.readLine().trimmed();
+        QRegularExpressionMatch m = rx.match(sub);
+        if (m.hasMatch()) {
+            s = m.captured(1);
+        }
     }
     return s;
 }
@@ -2486,17 +2490,18 @@ getRuntimeALSADriverVersion()
 int
 getRuntimeALSADriverNumber()
 {
-    QRegExp rx("(\\d+)");
+    QRegularExpression rx("(\\d+)");
     QString str = getRuntimeALSADriverVersion();
     bool ok;
-    int pos = 0, result = 0, j = 0;
-    while ((pos = rx.indexIn(str, pos)) != -1 && j < 3) {
-        int v = rx.cap(1).toInt(&ok);
+    int result = 0, j = 0;
+    QRegularExpressionMatchIterator i = rx.globalMatch(str);
+    while (i.hasNext() && (j < 3)) {
+        QRegularExpressionMatch m = i.next();
+        int v = m.captured(1).toInt(&ok);
         if (ok) {
             result <<= 8;
             result += v;
         }
-        pos += rx.matchedLength();
         j++;
     }
     return result;
