@@ -1,10 +1,10 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -16,18 +16,19 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <cmath>
-#include <cstdio>
+#include "errorcheck.h"
 #include <QReadLocker>
 #include <QWriteLocker>
+#include <cmath>
+#include <cstdio>
 #include <drumstick/alsatimer.h>
-
 /**
  * @file alsatimer.cpp
  * Implementation of classes managing ALSA Timers
  */
 
 namespace drumstick {
+namespace ALSA {
 
 /**
  * @addtogroup ALSATimer
@@ -77,7 +78,7 @@ namespace drumstick {
  *
  * This class represents an ALSA timer object.
  *
- * @see http://www.alsa-project.org/alsa-doc/alsa-lib/group___timer.html
+ * @see https://www.alsa-project.org/alsa-doc/alsa-lib/group___timer.html
  * @}
  */
 
@@ -130,10 +131,13 @@ TimerInfo::clone()
 /**
  * Assignment operator
  * @param other Existing TimerInfo object reference
+ * @return a reference of this object
  */
 TimerInfo&
 TimerInfo::operator=(const TimerInfo& other)
 {
+    if (this == &other)
+        return *this;
     snd_timer_info_copy(m_Info, other.m_Info);
     return *this;
 }
@@ -215,8 +219,8 @@ TimerInfo::getSizeOfInfo() const
 
 /**
  * Gets the maximum timer ticks
- * @deprecated
  * @return Maximum timer ticks
+ * @deprecated
  */
 long
 TimerInfo::getTicks()
@@ -308,6 +312,8 @@ TimerId::clone()
 TimerId&
 TimerId::operator=(const TimerId& other)
 {
+    if (this == &other)
+        return *this;
     snd_timer_id_copy(m_Info, other.m_Info);
     if (getCard() < 0)
     setCard(0);
@@ -442,7 +448,7 @@ TimerId::getSizeOfInfo() const
  */
 TimerQuery::TimerQuery(const QString& deviceName, int openMode)
 {
-    CHECK_WARNING( snd_timer_query_open( &m_Info,
+    DRUMSTICK_ALSA_CHECK_WARNING( snd_timer_query_open( &m_Info,
                                          deviceName.toLocal8Bit().data(),
                                          openMode ));
     readTimers();
@@ -457,7 +463,7 @@ TimerQuery::TimerQuery(const QString& deviceName, int openMode)
 TimerQuery::TimerQuery( const QString& deviceName, int openMode,
                         snd_config_t* conf )
 {
-    CHECK_WARNING( snd_timer_query_open_lconf( &m_Info,
+    DRUMSTICK_ALSA_CHECK_WARNING( snd_timer_query_open_lconf( &m_Info,
                                                deviceName.toLocal8Bit().data(),
                                                openMode, conf ));
     readTimers();
@@ -594,6 +600,8 @@ TimerGlobalInfo::clone()
 TimerGlobalInfo&
 TimerGlobalInfo::operator=(const TimerGlobalInfo& other)
 {
+    if (this == &other)
+        return *this;
     snd_timer_ginfo_copy(m_Info, other.m_Info);
     return *this;
 }
@@ -765,6 +773,8 @@ TimerParams::clone()
 TimerParams&
 TimerParams::operator=(const TimerParams& other)
 {
+    if (this == &other)
+        return *this;
     snd_timer_params_copy (m_Info, other.m_Info);
     return *this;
 }
@@ -953,6 +963,8 @@ TimerStatus::clone()
 TimerStatus&
 TimerStatus::operator=(const TimerStatus& other)
 {
+    if (this == &other)
+        return *this;
     snd_timer_status_copy (m_Info, other.m_Info);
     return *this;
 }
@@ -1030,12 +1042,12 @@ TimerStatus::getSizeOfInfo() const
  */
 Timer::Timer( const QString& deviceName, int openMode, QObject* parent )
     : QObject(parent),
-    m_asyncHandler(NULL),
-    m_handler(NULL),
-    m_thread(NULL),
+    m_asyncHandler(nullptr),
+    m_handler(nullptr),
+    m_thread(nullptr),
     m_deviceName(deviceName)
 {
-    CHECK_ERROR( snd_timer_open( &m_Info, m_deviceName.toLocal8Bit().data(),
+    DRUMSTICK_ALSA_CHECK_ERROR( snd_timer_open( &m_Info, m_deviceName.toLocal8Bit().data(),
                                  openMode ));
 }
 
@@ -1054,12 +1066,12 @@ Timer::Timer( const QString& deviceName, int openMode, QObject* parent )
 Timer::Timer( const QString& deviceName, int openMode, snd_config_t* conf,
               QObject* parent )
     : QObject(parent),
-    m_asyncHandler(NULL),
-    m_handler(NULL),
-    m_thread(NULL),
+    m_asyncHandler(nullptr),
+    m_handler(nullptr),
+    m_thread(nullptr),
     m_deviceName(deviceName)
 {
-    CHECK_ERROR( snd_timer_open_lconf( &m_Info,
+    DRUMSTICK_ALSA_CHECK_ERROR( snd_timer_open_lconf( &m_Info,
                                        m_deviceName.toLocal8Bit().data(),
                                        openMode, conf ));
 }
@@ -1077,9 +1089,9 @@ Timer::Timer( const QString& deviceName, int openMode, snd_config_t* conf,
  */
 Timer::Timer( TimerId& id, int openMode, QObject* parent )
     : QObject(parent),
-    m_asyncHandler(NULL),
-    m_handler(NULL),
-    m_thread(NULL)
+    m_asyncHandler(nullptr),
+    m_handler(nullptr),
+    m_thread(nullptr)
 {
     m_deviceName = QString("hw:CLASS=%1,SCLASS=%2,CARD=%3,DEV=%4,SUBDEV=%5")
     .arg(id.getClass())
@@ -1087,7 +1099,7 @@ Timer::Timer( TimerId& id, int openMode, QObject* parent )
     .arg(id.getCard())
     .arg(id.getDevice())
     .arg(id.getSubdevice());
-    CHECK_ERROR( snd_timer_open( &m_Info,
+    DRUMSTICK_ALSA_CHECK_ERROR( snd_timer_open( &m_Info,
                                  m_deviceName.toLocal8Bit().data(),
                                  openMode ));
 }
@@ -1110,9 +1122,9 @@ Timer::Timer( TimerId& id, int openMode, QObject* parent )
 Timer::Timer( int cls, int scls, int card, int dev, int sdev,
               int openMode, QObject* parent )
     : QObject(parent),
-    m_asyncHandler(NULL),
-    m_handler(NULL),
-    m_thread(NULL)
+    m_asyncHandler(nullptr),
+    m_handler(nullptr),
+    m_thread(nullptr)
 {
     m_deviceName = QString("hw:CLASS=%1,SCLASS=%2,CARD=%3,DEV=%4,SUBDEV=%5")
         .arg(cls)
@@ -1120,7 +1132,7 @@ Timer::Timer( int cls, int scls, int card, int dev, int sdev,
         .arg(card)
         .arg(dev)
         .arg(sdev);
-    CHECK_ERROR( snd_timer_open( &m_Info,
+    DRUMSTICK_ALSA_CHECK_ERROR( snd_timer_open( &m_Info,
                                  m_deviceName.toLocal8Bit().data(),
                                  openMode ));
 }
@@ -1131,9 +1143,9 @@ Timer::Timer( int cls, int scls, int card, int dev, int sdev,
 Timer::~Timer()
 {
     stopEvents();
-    if (m_thread != NULL)
+    if (m_thread != nullptr)
         delete m_thread;
-    CHECK_WARNING(snd_timer_close(m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_timer_close(m_Info));
 }
 
 /**
@@ -1144,7 +1156,7 @@ Timer::~Timer()
 void
 Timer::addAsyncTimerHandler(snd_async_callback_t callback, void *private_data)
 {
-    CHECK_WARNING(snd_async_add_timer_handler(&m_asyncHandler, m_Info, callback, private_data));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_async_add_timer_handler(&m_asyncHandler, m_Info, callback, private_data));
 }
 
 /**
@@ -1175,7 +1187,7 @@ Timer::getPollDescriptorsCount()
 void
 Timer::pollDescriptors(struct pollfd *pfds, unsigned int space)
 {
-    CHECK_WARNING(snd_timer_poll_descriptors(m_Info, pfds, space));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_timer_poll_descriptors(m_Info, pfds, space));
 }
 
 /**
@@ -1187,7 +1199,7 @@ Timer::pollDescriptors(struct pollfd *pfds, unsigned int space)
 void
 Timer::pollDescriptorsRevents(struct pollfd *pfds, unsigned int nfds, unsigned short *revents)
 {
-    CHECK_WARNING(snd_timer_poll_descriptors_revents(m_Info, pfds, nfds, revents));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_timer_poll_descriptors_revents(m_Info, pfds, nfds, revents));
 }
 
 /**
@@ -1208,7 +1220,7 @@ Timer::getTimerInfo()
 void
 Timer::setTimerParams(const TimerParams& params)
 {
-    CHECK_WARNING( snd_timer_params(m_Info, params.m_Info) );
+    DRUMSTICK_ALSA_CHECK_WARNING( snd_timer_params(m_Info, params.m_Info) );
 }
 
 /**
@@ -1218,7 +1230,7 @@ Timer::setTimerParams(const TimerParams& params)
 TimerStatus&
 Timer::getTimerStatus()
 {
-    CHECK_WARNING( snd_timer_status(m_Info, m_TimerStatus.m_Info) );
+    DRUMSTICK_ALSA_CHECK_WARNING( snd_timer_status(m_Info, m_TimerStatus.m_Info) );
     return m_TimerStatus;
 }
 
@@ -1228,7 +1240,7 @@ Timer::getTimerStatus()
 void
 Timer::start()
 {
-    CHECK_WARNING(snd_timer_start(m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_timer_start(m_Info));
 }
 
 /**
@@ -1237,7 +1249,7 @@ Timer::start()
 void
 Timer::stop()
 {
-    CHECK_WARNING(snd_timer_stop(m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_timer_stop(m_Info));
 }
 
 /**
@@ -1246,7 +1258,7 @@ Timer::stop()
 void
 Timer::continueRunning()
 {
-    CHECK_WARNING(snd_timer_continue(m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_timer_continue(m_Info));
 }
 
 /**
@@ -1277,7 +1289,7 @@ Timer::doEvents()
         int msecs = ((tr.tstamp.tv_sec - m_last_time.tv_sec) * 1000) +
                     round((tr.tstamp.tv_nsec - m_last_time.tv_nsec) / 1000000.0);
         m_last_time = tr.tstamp;
-        if ( m_handler != NULL )
+        if ( m_handler != nullptr )
             m_handler->handleTimerEvent(tr.val, msecs);
         else
             emit timerExpired(tr.val, msecs);
@@ -1290,7 +1302,7 @@ Timer::doEvents()
 void Timer::startEvents()
 {
     m_last_time = getTimerStatus().getTimestamp();
-    if (m_thread == NULL) {
+    if (m_thread == nullptr) {
         m_thread = new TimerInputThread(this, 500);
         m_thread->start();
     }
@@ -1302,7 +1314,7 @@ void Timer::startEvents()
 void Timer::stopEvents()
 {
     int counter = 0;
-    if (m_thread != NULL) {
+    if (m_thread != nullptr) {
         m_thread->stop();
         while (!m_thread->wait(500) && (counter < 10)) {
             counter++;
@@ -1398,11 +1410,11 @@ Timer::TimerInputThread::run()
 {
     int err, count;
     struct pollfd *fds;
-    if (m_timer == NULL) return;
+    if (m_timer == nullptr) return;
 
     count = m_timer->getPollDescriptorsCount();
     fds = (pollfd *) calloc(count, sizeof(struct pollfd));
-    if (fds == NULL) {
+    if (fds == nullptr) {
         qWarning() << "allocation error!";
         return;
     }
@@ -1410,14 +1422,16 @@ Timer::TimerInputThread::run()
     fds->revents = 0;
 
     try {
-        while (!stopped() && (m_timer != NULL)) {
+        while (!stopped() && (m_timer != nullptr)) {
             m_timer->pollDescriptors(fds, count);
             if ((err = poll(fds, count, m_Wait)) < 0) {
                 qWarning() << "poll error " << err << "(" << strerror(err) << ")";
+                free(fds);
                 return;
             }
             if (err == 0) {
                 qWarning() << "timer time out";
+                free(fds);
                 return;
             }
             m_timer->doEvents();
@@ -1449,4 +1463,6 @@ Timer::TimerInputThread::stop()
     m_Stopped = true;
 }
 
-} /* namespace drumstick */
+} // namespace ALSA
+} // namespace drumstick
+
