@@ -1,10 +1,10 @@
 /*
     MIDI Sequencer C++ library
-    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -16,23 +16,25 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+extern "C" {
+    #include <alsa/asoundlib.h>
+}
+
 #include <QReadLocker>
 #include <QWriteLocker>
-#include <drumstick/playthread.h>
 #include <drumstick/alsaclient.h>
 #include <drumstick/alsaqueue.h>
+#include <drumstick/playthread.h>
 
 /**
  * @file playthread.cpp
  * Implementation of a sequencer output thread
  */
 
-namespace drumstick {
-
 /**
  * @addtogroup PlayThread
  * @{
- *
+ * ALSA Sequencer easy playback functionality.
  * SequencerOutputThread provides MIDI sequence playback.
  *
  * This is an abstract class that must be extended providing
@@ -52,6 +54,9 @@ namespace drumstick {
  * @}
  */
 
+namespace drumstick {
+namespace ALSA {
+
 const int TIMEOUT = 100;
 
 /**
@@ -62,14 +67,14 @@ const int TIMEOUT = 100;
 SequencerOutputThread::SequencerOutputThread(MidiClient *seq, int portId)
     : QThread(),
     m_MidiClient(seq),
-    m_Queue(0),
+    m_Queue(nullptr),
     m_PortId(portId),
     m_Stopped(false),
     m_QueueId(0),
     m_npfds(0),
-    m_pfds(0)
+    m_pfds(nullptr)
 {
-    if (m_MidiClient != NULL) {
+    if (m_MidiClient != nullptr) {
         m_Queue = m_MidiClient->getQueue();
         m_QueueId = m_Queue->getId();
     }
@@ -96,8 +101,9 @@ SequencerOutputThread::stop()
 	QWriteLocker locker(&m_mutex);
     m_Stopped = true;
     locker.unlock();
-    while (isRunning())
+    while (isRunning()) {
         wait(TIMEOUT);
+    }
 }
 
 /**
@@ -107,7 +113,7 @@ SequencerOutputThread::stop()
 void
 SequencerOutputThread::sendEchoEvent(int tick)
 {
-    if (!stopRequested() && m_MidiClient != NULL) {
+    if (!stopRequested() && m_MidiClient != nullptr) {
         SystemEvent ev(SND_SEQ_EVENT_ECHO);
         ev.setSource(m_PortId);
         ev.setDestination(m_MidiClient->getClientId(), m_PortId);
@@ -123,10 +129,11 @@ SequencerOutputThread::sendEchoEvent(int tick)
 void
 SequencerOutputThread::sendSongEvent(SequencerEvent* ev)
 {
-    if (m_MidiClient != NULL) {
+    if (m_MidiClient != nullptr) {
         while (!stopRequested() &&
-               (snd_seq_event_output_direct(m_MidiClient->getHandle(), ev->getHandle()) < 0))
+               (snd_seq_event_output_direct(m_MidiClient->getHandle(), ev->getHandle()) < 0)) {
             poll(m_pfds, m_npfds, TIMEOUT);
+        }
     }
 }
 
@@ -136,10 +143,10 @@ SequencerOutputThread::sendSongEvent(SequencerEvent* ev)
 void
 SequencerOutputThread::drainOutput()
 {
-    if (m_MidiClient != NULL) {
-        while (!stopRequested() &&
-               (snd_seq_drain_output(m_MidiClient->getHandle()) < 0))
+    if (!stopRequested() && m_MidiClient != nullptr) {
+        while (!stopRequested() && (snd_seq_drain_output(m_MidiClient->getHandle()) < 0)) {
             poll(m_pfds, m_npfds, TIMEOUT);
+        }
     }
 }
 
@@ -149,12 +156,8 @@ SequencerOutputThread::drainOutput()
 void
 SequencerOutputThread::syncOutput()
 {
-    if (!stopRequested() && m_MidiClient != NULL) {
-        QueueStatus status = m_Queue->getStatus();
-        while (!stopRequested() && (status.getEvents() > 0)) {
-           usleep(TIMEOUT);
-           status = m_Queue->getStatus();
-        }
+    if (!stopRequested() && m_MidiClient != nullptr) {
+        m_MidiClient->synchronizeOutput();
     }
 }
 
@@ -163,11 +166,11 @@ SequencerOutputThread::syncOutput()
  */
 void SequencerOutputThread::run()
 {
-    unsigned int last_tick;
-    if (m_MidiClient != NULL) {
+    if (m_MidiClient != nullptr) {
         try  {
+            unsigned int last_tick;
             m_npfds = snd_seq_poll_descriptors_count(m_MidiClient->getHandle(), POLLOUT);
-            m_pfds = (pollfd*) alloca(m_npfds * sizeof(pollfd));
+            m_pfds = (pollfd*) calloc(m_npfds, sizeof(pollfd));
             snd_seq_poll_descriptors(m_MidiClient->getHandle(), m_pfds, m_npfds, POLLOUT);
             last_tick = getInitialPosition();
             if (last_tick == 0) {
@@ -178,32 +181,34 @@ void SequencerOutputThread::run()
             }
             while (!stopRequested() && hasNext()) {
                 SequencerEvent* ev = nextEvent();
+                if (!stopRequested() && !SequencerEvent::isConnectionChange(ev)) {
+                    sendSongEvent(ev);
+                }
                 if (getEchoResolution() > 0) {
                     while (!stopRequested() && (last_tick < ev->getTick())) {
                         last_tick += getEchoResolution();
                         sendEchoEvent(last_tick);
                     }
                 }
-                if (!stopRequested() && !SequencerEvent::isConnectionChange(ev))
-                    sendSongEvent(ev);
             }
             if (stopRequested()) {
                 m_Queue->clear();
-                emit stopped();
+                emit playbackStopped();
             } else {
                 drainOutput();
                 syncOutput();
                 if (stopRequested())
-                    emit stopped();
+                    emit playbackStopped();
                 else
-                    emit finished();
+                    emit playbackFinished();
             }
             m_Queue->stop();
         } catch (...) {
             qWarning("exception in output thread");
         }
         m_npfds = 0;
-        m_pfds = 0;
+        free(m_pfds);
+        m_pfds = nullptr;
     }
 }
 
@@ -218,5 +223,7 @@ void SequencerOutputThread::start( Priority priority )
     QThread::start( priority );
 }
 
-} /* namespace drumstick */
+} // namespace ALSA
+} // namespace drumstick
+
 
