@@ -1,10 +1,10 @@
 /*
     MIDI Sequencer C++ library 
-    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
  
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
  
     This library is distributed in the hope that it will be useful,
@@ -16,17 +16,19 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "errorcheck.h"
 #include <drumstick/alsaclient.h>
-
 /**
  * @file subscription.cpp
  * Implementation of classes managing ALSA sequencer subscriptions
  */
 
+/** @ingroup ALSAGroup */
 namespace drumstick {
+namespace ALSA {
 
 /**
- * @addtogroup ALSASubscription
+ * @addtogroup ALSASubs
  * @{
  *
  * Subscriptions are virtual MIDI cables between readable and writable ports.
@@ -42,7 +44,7 @@ namespace drumstick {
  *
  * Subscription: This class represents a connection between two ports.
  *
- * @see http://www.alsa-project.org/alsa-doc/alsa-lib/group___seq_subscribe.html
+ * @see https://www.alsa-project.org/alsa-doc/alsa-lib/group___seq_subscribe.html
  * @}
  */
 
@@ -98,6 +100,8 @@ Subscriber* Subscriber::clone()
  */
 Subscriber& Subscriber::operator=(const Subscriber& other)
 {
+    if (this == &other)
+        return *this;
     snd_seq_query_subscribe_copy(m_Info, other.m_Info);
     return *this;
 }
@@ -315,7 +319,7 @@ Subscription::Subscription(snd_seq_port_subscribe_t* other)
 Subscription::Subscription(MidiClient* seq)
 {
     snd_seq_port_subscribe_malloc(&m_Info);
-    CHECK_WARNING(snd_seq_get_port_subscription(seq->getHandle(), m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_get_port_subscription(seq->getHandle(), m_Info));
 }
 
 /**
@@ -345,6 +349,8 @@ Subscription::clone()
 Subscription&
 Subscription::operator=(const Subscription& other)
 {
+    if (this == &other)
+        return *this;
     snd_seq_port_subscribe_copy(m_Info, other.m_Info);
     return *this;
 }
@@ -506,11 +512,11 @@ Subscription::setDest(unsigned char client, unsigned char port)
 void
 Subscription::subscribe(MidiClient* seq)
 {
-    if ((m_Info == NULL) || (seq == NULL) || !(seq->isOpened()))
+    if ((m_Info == nullptr) || (seq == nullptr) || !(seq->isOpened()))
     {
         return;
     }
-    CHECK_WARNING(snd_seq_subscribe_port(seq->getHandle(), m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_subscribe_port(seq->getHandle(), m_Info));
 }
 
 /**
@@ -522,11 +528,11 @@ Subscription::subscribe(MidiClient* seq)
 void
 Subscription::unsubscribe(MidiClient* seq)
 {
-    if ((m_Info == NULL) || (seq == NULL) || !(seq->isOpened()))
+    if ((m_Info == nullptr) || (seq == nullptr) || !(seq->isOpened()))
     {
         return;
     }
-    CHECK_WARNING(snd_seq_unsubscribe_port(seq->getHandle(), m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_unsubscribe_port(seq->getHandle(), m_Info));
 }
 
 /**
@@ -539,5 +545,6 @@ Subscription::getSizeOfInfo() const
     return snd_seq_port_subscribe_sizeof();
 }
 
-} /* namespace drumstick */
+} // namespace ALSA
+} // namespace drumstick
 
