@@ -1,10 +1,10 @@
 /*
     Drumstick RT Backend using the ALSA Sequencer
-    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -16,22 +16,24 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QMutexLocker>
-#include <cmath>
-#include <drumstick/alsaclient.h>
-#include <drumstick/alsaport.h>
-#include <drumstick/alsaevent.h>
-#include <drumstick/rtmidioutput.h>
 #include "alsamidiinput.h"
+#include <QMap>
+#include <QStringList>
+#include <drumstick/alsaclient.h>
+#include <drumstick/alsaevent.h>
+#include <drumstick/alsaport.h>
+#include <drumstick/rtmidioutput.h>
 
-namespace drumstick {
-namespace rt {
+namespace drumstick { namespace rt {
 
-    static QString DEFAULT_PUBLIC_NAME(QLatin1String("MIDI In"));
+    using namespace ALSA;
+
+    const QString ALSAMIDIInput::DEFAULT_PUBLIC_NAME = QStringLiteral("MIDI In");
 
     class ALSAMIDIInput::ALSAMIDIInputPrivate : public SequencerEventHandler
     {
     public:
+
         ALSAMIDIInput *m_inp;
         MIDIOutput *m_out;
         MidiClient *m_client;
@@ -42,44 +44,75 @@ namespace rt {
         bool m_clientFilter;
         int m_runtimeAlsaNum;
         QString m_publicName;
-        QString m_currentInput;
-        QStringList m_inputDevices;
+        MIDIConnection m_currentInput;
+        QList<MIDIConnection> m_inputDevices;
         QStringList m_excludedNames;
-        QMutex m_openMutex;
+        bool m_initialized;
+        bool m_status;
+        QStringList m_diagnostics;
 
-        ALSAMIDIInputPrivate(ALSAMIDIInput *inp) :
+        explicit ALSAMIDIInputPrivate(ALSAMIDIInput *inp) :
             m_inp(inp),
-            m_out(0),
-            m_client(0),
-            m_port(0),
+            m_out(nullptr),
+            m_client(nullptr),
+            m_port(nullptr),
             m_portId(-1),
             m_clientId(-1),
             m_thruEnabled(false),
-            m_publicName(DEFAULT_PUBLIC_NAME)
+            m_clientFilter(false),
+            m_publicName(ALSAMIDIInput::DEFAULT_PUBLIC_NAME),
+            m_initialized(false),
+            m_status(false)
         {
             m_runtimeAlsaNum = getRuntimeALSALibraryNumber();
-            m_client = new MidiClient(m_inp);
-            m_client->open();
-            m_client->setClientName(m_publicName);
-            m_port = m_client->createPort();
-            m_port->setPortName("in");
-            m_port->setCapability( SND_SEQ_PORT_CAP_WRITE | SND_SEQ_PORT_CAP_SUBS_WRITE );
-            m_port->setPortType( SND_SEQ_PORT_TYPE_APPLICATION | SND_SEQ_PORT_TYPE_MIDI_GENERIC );
-            m_clientId = m_client->getClientId();
-            m_portId = m_port->getPortId();
-            m_port->setTimestamping(false);
-            m_port->setTimestampReal(false);
-            m_client->setHandler(this);
         }
 
         virtual ~ALSAMIDIInputPrivate()
         {
-            if (m_client != NULL) {
+            if (m_initialized) {
                 clearSubscription();
-                if (m_port != NULL)
+                uninitialize();
+            }
+        }
+
+        void initialize() {
+            //qDebug() << Q_FUNC_INFO << m_initialized;
+            if (!m_initialized) {
+                m_client = new MidiClient(m_inp);
+                m_client->open();
+                m_client->setClientName(m_publicName);
+                m_port = m_client->createPort();
+                m_port->setPortName("in");
+                m_port->setCapability( SND_SEQ_PORT_CAP_WRITE | SND_SEQ_PORT_CAP_SUBS_WRITE );
+                m_port->setPortType( SND_SEQ_PORT_TYPE_APPLICATION | SND_SEQ_PORT_TYPE_MIDI_GENERIC );
+                m_clientId = m_client->getClientId();
+                m_portId = m_port->getPortId();
+                m_port->setTimestamping(false);
+                m_port->setTimestampReal(false);
+                m_client->setHandler(this);
+                m_initialized = true;
+                m_status = true;
+                m_diagnostics.clear();
+                m_client->startSequencerInput();
+            }
+        }
+
+        void uninitialize() {
+            //qDebug() << Q_FUNC_INFO << m_initialized;
+            if (m_initialized) {
+                if (m_port != nullptr) {
                     m_port->detach();
-                m_client->close();
-                delete m_client;
+                    delete m_port;
+                    m_port = nullptr;
+                }
+                if (m_client != nullptr) {
+                    m_client->close();
+                    delete m_client;
+                    m_client = nullptr;
+                }
+                m_initialized = false;
+                m_status = false;
+                m_diagnostics.clear();
             }
         }
 
@@ -96,41 +129,64 @@ namespace rt {
 
         void reloadDeviceList(bool advanced)
         {
+            QStringList clientNames;
+            QMap<QString,int> namesMap;
+            if (!m_initialized) {
+                initialize();
+            }
+            auto inputs = m_client->getAvailableInputs();
             m_clientFilter = !advanced;
             m_inputDevices.clear();
-            QListIterator<PortInfo> it(m_client->getAvailableInputs());
-            while(it.hasNext()) {
+            m_inputDevices << MIDIConnection();
+            for (const PortInfo& p : qAsConst(inputs)) {
+                QString name = p.getClientName();
+                clientNames << name;
+                if (namesMap.contains(name)) {
+                    namesMap[name]++;
+                } else {
+                    namesMap.insert(name, 1);
+                }
+            }
+            for (PortInfo& p : inputs) {
                 bool excluded = false;
-                PortInfo p = it.next();
-                QString name = QString("%1:%2").arg(p.getClientName()).arg(p.getPort());
+                QString name = p.getClientName();
                 if (m_clientFilter && clientIsAdvanced(p.getClient()))
                     continue;
-                if ( m_clientFilter && name.startsWith(QLatin1String("Virtual Raw MIDI")) )
+                if ( m_clientFilter && name.startsWith(QStringLiteral("Virtual Raw MIDI")) )
                     continue;
                 if ( name.startsWith(m_publicName) )
                     continue;
-                foreach(const QString& n, m_excludedNames) {
+                for (const QString& n : qAsConst(m_excludedNames)) {
                     if (name.startsWith(n)) {
                         excluded = true;
                         break;
                     }
                 }
-                if (!excluded)
-                    m_inputDevices << name;
+                if (!excluded) {
+                    int k = clientNames.count(name) + 1;
+                    QString addr = QString("%1:%2").arg(p.getClient()).arg(p.getPort());
+                    if (k > 2) {
+                        m_inputDevices << MIDIConnection(QString("%1 (%2)").arg(name).arg(k - namesMap[name]--), addr);
+                    } else {
+                        m_inputDevices << MIDIConnection(name, addr);
+                    }
+                }
             }
-            if (!m_currentInput.isEmpty() && !m_inputDevices.contains(m_currentInput)) {
-                m_currentInput.clear();
+            if (!m_currentInput.first.isEmpty() &&
+                !m_inputDevices.contains(m_currentInput)) {
+                m_currentInput = MIDIConnection();
             }
         }
 
-        bool setSubscription(const QString &newDevice)
+        bool setSubscription(const MIDIConnection &newDevice)
         {
-            //qDebug() << Q_FUNC_INFO << newDevice;
+            if (!m_initialized) {
+                initialize();
+            }
             if (m_inputDevices.contains(newDevice)) {
                 m_currentInput = newDevice;
                 m_port->unsubscribeAll();
-                m_port->subscribeFrom(newDevice);
-                m_client->startSequencerInput();
+                m_port->subscribeFrom(newDevice.second.toString());
                 return true;
             }
             return false;
@@ -138,28 +194,30 @@ namespace rt {
 
         void clearSubscription()
         {
-            if (!m_currentInput.isEmpty()) {
+            if (!m_currentInput.first.isEmpty() && m_initialized) {
                 m_client->stopSequencerInput();
                 m_port->unsubscribeAll();
-                m_currentInput.clear();
+                m_currentInput = MIDIConnection();
             }
         }
 
         void setPublicName(QString newName)
         {
             if (newName != m_publicName) {
-                m_client->setClientName(newName);
                 m_publicName = newName;
+                if(m_initialized) {
+                    m_client->setClientName(newName);
+                }
             }
         }
 
-        void handleSequencerEvent(SequencerEvent* ev)
+        void handleSequencerEvent(SequencerEvent* ev) override
         {
-            if ( !SequencerEvent::isConnectionChange(ev) )
+            if ( !SequencerEvent::isConnectionChange(ev) && m_initialized)
                 switch(ev->getSequencerType()) {
                 case SND_SEQ_EVENT_NOTEOFF: {
                         const NoteOffEvent* n = static_cast<const NoteOffEvent*>(ev);
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendNoteOff(n->getChannel(), n->getKey(), n->getVelocity());
                         }
                         emit m_inp->midiNoteOff(n->getChannel(), n->getKey(), n->getVelocity());
@@ -167,7 +225,7 @@ namespace rt {
                     break;
                 case SND_SEQ_EVENT_NOTEON: {
                         const NoteOnEvent* n = static_cast<const NoteOnEvent*>(ev);
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendNoteOn(n->getChannel(), n->getKey(), n->getVelocity());
                         }
                         emit m_inp->midiNoteOn(n->getChannel(), n->getKey(), n->getVelocity());
@@ -175,7 +233,7 @@ namespace rt {
                     break;
                 case SND_SEQ_EVENT_KEYPRESS: {
                         const KeyPressEvent* n = static_cast<const KeyPressEvent*>(ev);
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendKeyPressure(n->getChannel(), n->getKey(), n->getVelocity());
                         }
                         emit m_inp->midiKeyPressure(n->getChannel(), n->getKey(), n->getVelocity());
@@ -184,7 +242,7 @@ namespace rt {
                 case SND_SEQ_EVENT_CONTROLLER:
                 case SND_SEQ_EVENT_CONTROL14: {
                         const ControllerEvent* n = static_cast<const ControllerEvent*>(ev);
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendController(n->getChannel(), n->getParam(), n->getValue());
                         }
                         emit m_inp->midiController(n->getChannel(), n->getParam(), n->getValue());
@@ -192,7 +250,7 @@ namespace rt {
                     break;
                 case SND_SEQ_EVENT_PGMCHANGE: {
                         const ProgramChangeEvent* p = static_cast<const ProgramChangeEvent*>(ev);
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendProgram(p->getChannel(), p->getValue());
                         }
                         emit m_inp->midiProgram(p->getChannel(), p->getValue());
@@ -200,7 +258,7 @@ namespace rt {
                     break;
                 case SND_SEQ_EVENT_CHANPRESS: {
                         const ChanPressEvent* n = static_cast<const ChanPressEvent*>(ev);
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendChannelPressure(n->getChannel(), n->getValue());
                         }
                         emit m_inp->midiChannelPressure(n->getChannel(), n->getValue());
@@ -208,7 +266,7 @@ namespace rt {
                     break;
                 case SND_SEQ_EVENT_PITCHBEND: {
                         const PitchBendEvent* n = static_cast<const PitchBendEvent*>(ev);
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendPitchBend(n->getChannel(), n->getValue());
                         }
                         emit m_inp->midiPitchBend(n->getChannel(), n->getValue());
@@ -217,7 +275,7 @@ namespace rt {
                 case SND_SEQ_EVENT_SYSEX: {
                         const SysExEvent* n = static_cast<const SysExEvent*>(ev);
                         QByteArray data(n->getData(), n->getLength());
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendSysex(data);
                         }
                         emit m_inp->midiSysex(data);
@@ -226,7 +284,7 @@ namespace rt {
                 case SND_SEQ_EVENT_SYSTEM: {
                         const SystemEvent* n = static_cast<const SystemEvent*>(ev);
                         int status = (int) n->getRaw8(0);
-                        if(m_out != 0 && m_thruEnabled) {
+                        if(m_out != nullptr && m_thruEnabled) {
                             m_out->sendSystemMsg(status);
                         }
                         if (status < 0xF7)
@@ -254,11 +312,12 @@ namespace rt {
     void ALSAMIDIInput::initialize(QSettings* settings)
     {
         Q_UNUSED(settings)
+        d->initialize();
     }
 
     QString ALSAMIDIInput::backendName()
     {
-        return QLatin1String("ALSA");
+        return QStringLiteral("ALSA");
     }
 
     QString ALSAMIDIInput::publicName()
@@ -271,7 +330,7 @@ namespace rt {
         d->setPublicName(name);
     }
 
-    QStringList ALSAMIDIInput::connections(bool advanced)
+    QList<MIDIConnection> ALSAMIDIInput::connections(bool advanced)
     {
         d->reloadDeviceList(advanced);
         return d->m_inputDevices;
@@ -282,17 +341,21 @@ namespace rt {
         d->m_excludedNames = conns;
     }
 
-    void ALSAMIDIInput::open(QString name)
+    void ALSAMIDIInput::open(const MIDIConnection& name)
     {
-        d->setSubscription(name);
+        auto b = d->setSubscription(name);
+        if (!b) {
+            d->m_diagnostics << "failed subscription to " + name.first;
+        }
     }
 
     void ALSAMIDIInput::close()
     {
         d->clearSubscription();
+        d->uninitialize();
     }
 
-    QString ALSAMIDIInput::currentConnection()
+    MIDIConnection ALSAMIDIInput::currentConnection()
     {
         return d->m_currentInput;
     }
@@ -309,7 +372,18 @@ namespace rt {
 
     bool ALSAMIDIInput::isEnabledMIDIThru()
     {
-        return d->m_thruEnabled && (d->m_out != 0);
+        return d->m_thruEnabled && (d->m_out != nullptr);
     }
 
-}}
+    QStringList ALSAMIDIInput::getDiagnostics()
+    {
+        return d->m_diagnostics;
+    }
+
+    bool ALSAMIDIInput::getStatus()
+    {
+        return d->m_status;
+    }
+
+} // namespace rt
+} // namespace drumstick
