@@ -27,6 +27,9 @@
  *----------------------------------------------------------------------------
 */
 
+#define LOG_TAG "Sonivox"
+//#include "log/log.h"
+
 #include "eas_synthcfg.h"
 #include "eas.h"
 #include "eas_config.h"
@@ -465,19 +468,18 @@ EAS_PUBLIC EAS_RESULT EAS_Init (EAS_DATA_HANDLE *ppEASData)
 */
 EAS_PUBLIC EAS_RESULT EAS_Shutdown (EAS_DATA_HANDLE pEASData)
 {
-    EAS_HW_DATA_HANDLE hwInstData;
-    EAS_RESULT result, reportResult;
-    EAS_INT i;
-
-    /* establish pointers */
-    hwInstData = pEASData->hwInstData;
-
     /* check for NULL handle */
     if (!pEASData)
         return EAS_ERROR_HANDLE_INTEGRITY;
 
+    /* establish pointers */
+    EAS_HW_DATA_HANDLE hwInstData = pEASData->hwInstData;
+
     /* if there are streams open, close them */
-    reportResult = EAS_SUCCESS;
+    EAS_RESULT reportResult = EAS_SUCCESS;
+
+    EAS_RESULT result;
+    EAS_INT i;
     for (i = 0; i < MAX_NUMBER_STREAMS; i++)
     {
         if (pEASData->streams[i].pParserModule && pEASData->streams[i].handle)
@@ -1246,6 +1248,14 @@ static EAS_RESULT EAS_ParseEvents (S_EAS_DATA *pEASData, EAS_HANDLE pStream, EAS
     EAS_INT yieldCount = YIELD_EVENT_COUNT;
     EAS_U32 time = 0;
 
+    // This constant is the maximum number of events that can be processed in a single time slice.
+    // A typical ringtone will contain a few events per time slice.
+    // Extremely dense ringtones might go up to 50 events.
+    // If we see this many events then the file is probably stuck in an infinite loop
+    // and should be aborted.
+    static const EAS_INT MAX_EVENT_COUNT = 100000;
+    EAS_INT eventCount = 0;
+
     /* does this parser have a time function? */
     pParserModule = pStream->pParserModule;
     if (pParserModule->pfTime == NULL)
@@ -1292,9 +1302,25 @@ static EAS_RESULT EAS_ParseEvents (S_EAS_DATA *pEASData, EAS_HANDLE pStream, EAS
             {
 
                 /* parse the next event */
-                if (pParserModule->pfEvent)
-                    if ((result = (*pParserModule->pfEvent)(pEASData, pStream->handle, parseMode)) != EAS_SUCCESS)
+                if (pParserModule->pfEvent) {
+                    if ((result = (*pParserModule->pfEvent)(pEASData, pStream->handle, parseMode))
+                            != EAS_SUCCESS) {
+						//ALOGE("%s() pfEvent returned %ld", __func__, result);
                         return result;
+                    }
+                }
+
+                // An infinite loop within a ringtone file can cause this function
+                // to loop forever.  Try to detect that and return an error.
+                // Only check when playing. Otherwise a very large file could be rejected
+                // when scanning the entire file in a single call to this function.
+                // OTA files will only do infinite loops when in eParserModePlay.
+                if (++eventCount >= MAX_EVENT_COUNT && parseMode == eParserModePlay) {
+					//ALOGE("%s() aborting, %d events. Infinite loop in song file?!",
+					//        __func__, eventCount);
+					//android_errorWriteLog(0x534e4554, "68664359");
+                    return EAS_ERROR_FILE_POS;
+                }
             }
 
             /* no more events in this frame, advance time */
