@@ -32,6 +32,9 @@
  * includes
  *------------------------------------
 */
+//#include "log/log.h"
+//#include <cutils/log.h>
+
 #include "eas_types.h"
 #include "eas_math.h"
 #include "eas_audioconst.h"
@@ -57,7 +60,7 @@ extern void WT_Interpolate (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame);
 extern void WT_VoiceFilter (S_FILTER_CONTROL*pFilter, S_WT_INT_FRAME *pWTIntFrame);
 #endif
 
-#if defined(_OPTIMIZED_MONO) || !defined(NATIVE_EAS_KERNEL)
+#if defined(_OPTIMIZED_MONO) || !defined(NATIVE_EAS_KERNEL) || defined(_16_BIT_SAMPLES)
 /*----------------------------------------------------------------------------
  * WT_VoiceGain
  *----------------------------------------------------------------------------
@@ -88,6 +91,11 @@ void WT_VoiceGain (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
 
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
+    if (numSamples <= 0) {
+		//ALOGE("b/26366256");
+		//android_errorWriteLog(0x534e4554, "26366256");
+        return;
+    }
     pMixBuffer = pWTIntFrame->pMixBuffer;
     pInputBuffer = pWTIntFrame->pAudioBuffer;
 
@@ -155,7 +163,7 @@ void WT_VoiceGain (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
 }
 #endif
 
-#ifndef NATIVE_EAS_KERNEL
+#if !defined(NATIVE_EAS_KERNEL) || defined(_16_BIT_SAMPLES)
 /*----------------------------------------------------------------------------
  * WT_Interpolate
  *----------------------------------------------------------------------------
@@ -182,6 +190,11 @@ void WT_Interpolate (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
 
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
+    if (numSamples <= 0) {
+		//ALOGE("b/26366256");
+		//android_errorWriteLog(0x534e4554, "26366256");
+        return;
+    }
     pOutputBuffer = pWTIntFrame->pAudioBuffer;
 
     loopEnd = (const EAS_SAMPLE*) pWTVoice->loopEnd + 1;
@@ -249,7 +262,7 @@ void WT_Interpolate (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
 }
 #endif
 
-#ifndef NATIVE_EAS_KERNEL
+#if !defined(NATIVE_EAS_KERNEL) || defined(_16_BIT_SAMPLES)
 /*----------------------------------------------------------------------------
  * WT_InterpolateNoLoop
  *----------------------------------------------------------------------------
@@ -275,6 +288,11 @@ void WT_InterpolateNoLoop (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
 
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
+    if (numSamples <= 0) {
+		//ALOGE("b/26366256");
+		//android_errorWriteLog(0x534e4554, "26366256");
+        return;
+    }
     pOutputBuffer = pWTIntFrame->pAudioBuffer;
 
     phaseInc = pWTIntFrame->frame.phaseIncrement;
@@ -363,6 +381,11 @@ void WT_VoiceFilter (S_FILTER_CONTROL *pFilter, S_WT_INT_FRAME *pWTIntFrame)
 
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
+    if (numSamples <= 0) {
+		//ALOGE("b/26366256");
+		//android_errorWriteLog(0x534e4554, "26366256");
+        return;
+    }
     pAudioBuffer = pWTIntFrame->pAudioBuffer;
 
     z1 = pFilter->z1;
@@ -426,6 +449,11 @@ void WT_VoiceFilter (S_FILTER_CONTROL *pFilter, S_WT_INT_FRAME *pWTIntFrame)
 
     /* initialize some local variables */
     numSamples = pWTIntFrame->numSamples;
+    if (numSamples <= 0) {
+		//ALOGE("b/26366256");
+		//android_errorWriteLog(0x534e4554, "26366256");
+        return;
+    }
     pOutputBuffer = pWTIntFrame->pAudioBuffer;
     phaseInc = pWTIntFrame->frame.phaseIncrement;
 
@@ -569,6 +597,11 @@ void WT_InterpolateMono (S_WT_VOICE *pWTVoice, S_WT_INT_FRAME *pWTIntFrame)
     EAS_I8 *pLoopStart;
 
     numSamples = pWTIntFrame->numSamples;
+    if (numSamples <= 0) {
+        ALOGE("b/26366256");
+        android_errorWriteLog(0x534e4554, "26366256");
+        return;
+    }
     pMixBuffer = pWTIntFrame->pMixBuffer;
 
     /* calculate gain increment */
