@@ -1,10 +1,10 @@
 /*
     Drumstick RT (realtime MIDI In/Out)
-    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -42,15 +42,17 @@ public:
     quint16 m_port;
     QString m_publicName;
     QHostAddress m_groupAddress;
-    QString m_currentInput;
-    QStringList m_inputDevices;
+    MIDIConnection m_currentInput;
+    QList<MIDIConnection> m_inputDevices;
     QStringList m_excludedNames;
     QNetworkInterface m_iface;
     bool m_ipv6;
+    bool m_status;
+    QStringList m_diagnostics;
 
-    NetMIDIInputPrivate(QObject *parent = nullptr);
+    explicit NetMIDIInputPrivate(QObject *parent = nullptr);
 
-    void open(QString portName);
+    void open(const MIDIConnection& conn);
     void close();
     void initialize(QSettings* settings);
     void setMIDIThruDevice(MIDIOutput* device);
