@@ -1,10 +1,10 @@
 /*
     Drumstick RT (realtime MIDI In/Out)
-    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -18,8 +18,9 @@
 
 #include "ossinput.h"
 
-namespace drumstick {
-namespace rt {
+namespace drumstick { namespace rt {
+
+const QString OSSInput::DEFAULT_PUBLIC_NAME = QStringLiteral("MIDI In");
 
 OSSInput::OSSInput(QObject *parent) : MIDIInput(parent),
     d(new OSSInputPrivate(this))
@@ -50,7 +51,7 @@ void OSSInput::setPublicName(QString name)
     d->m_publicName = name;
 }
 
-QStringList OSSInput::connections(bool advanced)
+QList<MIDIConnection> OSSInput::connections(bool advanced)
 {
     d->reloadDeviceList(advanced);
     return d->m_inputDevices;
@@ -61,14 +62,14 @@ void OSSInput::setExcludedConnections(QStringList conns)
     Q_UNUSED(conns)
 }
 
-QString OSSInput::currentConnection()
+MIDIConnection OSSInput::currentConnection()
 {
     return d->m_currentInput;
 }
 
-void OSSInput::open(QString name)
+void OSSInput::open(const MIDIConnection& conn)
 {
-    d->open(name);
+    d->open(conn);
 }
 
 void OSSInput::close()
@@ -89,7 +90,8 @@ void OSSInput::enableMIDIThru(bool enable)
 
 bool OSSInput::isEnabledMIDIThru()
 {
-    return d->m_thruEnabled && (d->m_out != 0);
+    return d->m_thruEnabled && (d->m_out != nullptr);
 }
 
-}}
+} // namespace rt
+} // namespace drumstick
