@@ -1,6 +1,6 @@
 /*
     Standard MIDI File dump program
-    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     Based on midifile.c by Tim Thompson, M.Czeiszperger and Greg Lee
 
@@ -29,6 +29,9 @@
 #include <cstdlib>
 #include <drumstick/qsmf.h>
 
+DISABLE_WARNING_PUSH
+DISABLE_WARNING_DEPRECATED_DECLARATIONS
+
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
 #define right Qt::right
 #define left Qt::left
@@ -293,3 +296,4 @@ int main(int argc, char **argv)
     return spy.numErrors();
 }
 
+DISABLE_WARNING_POP
