@@ -27,9 +27,9 @@ p, li { white-space: pre-wrap; }
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Using Qt version: %QT_VERSION%&lt;/p&gt;
 &lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Sample application for the &lt;/span&gt;&lt;a href=&quot;http://drumstick.sourceforge.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Drumstick MIDI Sequencer C++ library&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2021, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2022, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
@@ -38,12 +38,12 @@ p, li { white-space: pre-wrap; }
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;Drumstick MIDI Player %VERSION%&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:16pt; font-weight:600;&quot;&gt;Drumstick ALSA MIDI Player %VERSION%&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Using Qt version: %QT_VERSION%&lt;/p&gt;
 &lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Sample application for the &lt;/span&gt;&lt;a href=&quot;http://drumstick.sourceforge.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Drumstick MIDI Sequencer C++ library&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2021, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2022, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
@@ -71,210 +71,248 @@ p, li { white-space: pre-wrap; }
         <translation>Přehrávač MIDI Palička</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="186"/>
+        <location filename="guiplayer.ui" line="155"/>
         <source>Playback time and current levels</source>
         <translation>Čas přehrávání a nynější úrovně</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="227"/>
+        <location filename="guiplayer.ui" line="196"/>
         <source>00:00:00</source>
         <translation>00:00:00</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="234"/>
+        <location filename="guiplayer.ui" line="203"/>
         <source>Tempo:</source>
         <translation>Tempo:</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="257"/>
+        <location filename="guiplayer.ui" line="226"/>
         <source>Volume:</source>
         <translation>Hlasitost:</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="271"/>
+        <location filename="guiplayer.ui" line="240"/>
         <source>Pitch:</source>
         <translation>Výška tónu:</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="284"/>
+        <location filename="guiplayer.ui" line="253"/>
         <source>Pitch Control</source>
         <translation>Ovládání výšky tónu</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="287"/>
+        <location filename="guiplayer.ui" line="256"/>
         <source>Pitch transpose between -12 and +12 semitones</source>
         <translation>Transpozice výšky tónu mezi -12 a +12 půltóny</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="303"/>
+        <location filename="guiplayer.ui" line="272"/>
         <source>Reset Volume</source>
         <translation>Obnovit výchozí hlasitost</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="306"/>
+        <location filename="guiplayer.ui" line="275"/>
         <source>Reset Volume to 100%</source>
         <translation>Obnovit výchozí hlasitost na 100 %</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="326"/>
+        <location filename="guiplayer.ui" line="295"/>
         <source>Volume Slider</source>
         <translation>Posuvník hlasitosti</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="354"/>
+        <location filename="guiplayer.ui" line="323"/>
         <source>Playback progress</source>
         <translation>Postup přehrávání</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="378"/>
+        <location filename="guiplayer.ui" line="347"/>
         <source>File Name:</source>
         <translation>Název souboru:</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="391"/>
+        <location filename="guiplayer.ui" line="360"/>
         <source>Currently loaded MIDI file name</source>
         <translation>Nyní nahraný název souboru MIDI</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="412"/>
+        <location filename="guiplayer.ui" line="381"/>
         <source>Tempo Slider</source>
         <translation>Posuvník tempa</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="449"/>
+        <location filename="guiplayer.ui" line="418"/>
         <source>Reset Tempo</source>
         <translation>Obnovit výchozí tempo</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="452"/>
+        <location filename="guiplayer.ui" line="421"/>
         <source>Reset Tempo to 100%</source>
         <translation>Obnovit výchozí tempo na 100 %</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="455"/>
+        <location filename="guiplayer.ui" line="424"/>
         <source>tempo=100%</source>
         <translation>Tempo = 100 %</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="472"/>
+        <location filename="guiplayer.ui" line="441"/>
         <source>File</source>
         <translation>Soubor</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="484"/>
+        <location filename="guiplayer.ui" line="453"/>
         <source>Help</source>
         <translation>Nápověda</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="491"/>
+        <location filename="guiplayer.ui" line="460"/>
         <source>Settings</source>
         <translation>Nastavení</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="504"/>
+        <location filename="guiplayer.ui" line="473"/>
         <source>Tool Bar</source>
         <translation>Nástrojový pruh</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="532"/>
+        <location filename="guiplayer.ui" line="501"/>
         <source>Open</source>
         <translation>Otevřít</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="535"/>
+        <location filename="guiplayer.ui" line="504"/>
         <source>Open a MIDI file</source>
         <translation>Otevřít soubor MIDI</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="544"/>
+        <location filename="guiplayer.ui" line="513"/>
         <source>Quit</source>
         <translation>Ukončit</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="547"/>
+        <location filename="guiplayer.ui" line="516"/>
         <source>Quit the application</source>
         <translation>Ukončit program</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="556"/>
+        <location filename="guiplayer.ui" line="525"/>
         <source>Play</source>
         <translation>Přehrát</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="559"/>
+        <location filename="guiplayer.ui" line="528"/>
         <source>Start playing the current MIDI file</source>
         <translation>Spustit přehrávání nynějšího souboru MIDI</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="577"/>
+        <location filename="guiplayer.ui" line="546"/>
         <source>Pause</source>
         <translation>Pozastavit</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="580"/>
+        <location filename="guiplayer.ui" line="549"/>
         <source>Pause the playback</source>
         <translation>Pozastavit přehrávání</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="592"/>
+        <location filename="guiplayer.ui" line="561"/>
         <source>Stop</source>
         <translation>Zastavit</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="595"/>
+        <location filename="guiplayer.ui" line="564"/>
         <source>Stop the playback</source>
         <translation>Zastavit přehrávání</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="607"/>
+        <location filename="guiplayer.ui" line="576"/>
         <source>About</source>
         <translation>O programu</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="610"/>
+        <location filename="guiplayer.ui" line="579"/>
         <source>Show the about box</source>
         <translation>Ukázat okno O programu</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="619"/>
+        <location filename="guiplayer.ui" line="588"/>
         <source>About Qt</source>
         <translation>O Qt</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="622"/>
+        <location filename="guiplayer.ui" line="591"/>
         <source>Show the about Qt dialog box</source>
         <translation>Ukázat okno O Qt</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="631"/>
+        <location filename="guiplayer.ui" line="600"/>
         <source>MIDI Setup</source>
         <translation>Nastavení MIDI</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="634"/>
+        <location filename="guiplayer.ui" line="603"/>
         <source>Select a connection for the MIDI output port</source>
         <translation>Vybrat spojení pro výstupní přípojku MIDI</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="645"/>
-        <location filename="guiplayer.ui" line="648"/>
+        <location filename="guiplayer.ui" line="614"/>
+        <location filename="guiplayer.ui" line="617"/>
         <source>Show Tool Bar</source>
         <translation>Ukázat nástrojový pruh</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="651"/>
+        <location filename="guiplayer.ui" line="620"/>
         <source>Show or hide the tool bar</source>
         <translation>Ukázat nebo skrýt nástrojový pruh</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="662"/>
+        <location filename="guiplayer.ui" line="631"/>
         <source>Show Status Bar</source>
         <translation>Ukázat stavový řádek</translation>
     </message>
     <message>
-        <location filename="guiplayer.ui" line="665"/>
+        <location filename="guiplayer.ui" line="634"/>
         <source>Show or hide the status bar</source>
         <translation>Ukázat nebo skrýt stavový řádek</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <location filename="playermain.cpp" line="30"/>
+        <source>ALSA Sequencer based MIDI file player</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="playermain.cpp" line="32"/>
+        <source>Fatal error from the ALSA sequencer. This usually happens when the kernel doesn&apos;t have ALSA support, or the device node (/dev/snd/seq) doesn&apos;t exists, or the kernel module (snd_seq) is not loaded. Please check your ALSA/MIDI configuration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="playermain.cpp" line="77"/>
+        <source>MIDI Out Connection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="playermain.cpp" line="79"/>
+        <source>Input SMF/KAR/RMI/WRK file name.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="playermain.cpp" line="88"/>
+        <source>File not found: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="playermain.cpp" line="103"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="playermain.cpp" line="105"/>
+        <source>Returned error was: </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
