@@ -1,6 +1,6 @@
 /*
     SMF GUI Player test using the MIDI Sequencer C++ library
-    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 #include <QTextCodec>
 #include <QToolTip>
 #include <QUrl>
-#include <QTextCodec>
 #include <qmath.h>
 
 #include "guiplayer.h"
@@ -49,12 +48,15 @@
 #include <drumstick/rmid.h>
 #include <drumstick/sequencererror.h>
 
+DISABLE_WARNING_PUSH
+DISABLE_WARNING_DEPRECATED_DECLARATIONS
+
 using namespace drumstick;
 using namespace ALSA;
 using namespace File;
 
 const QString GUIPlayer::QSTR_DOMAIN = QStringLiteral("drumstick.sourceforge.net");
-const QString GUIPlayer::QSTR_APPNAME = QStringLiteral("GUIPlayer");
+const QString GUIPlayer::QSTR_APPNAME = QStringLiteral("drumstick-guiplayer");
 
 GUIPlayer::GUIPlayer(QWidget *parent, Qt::WindowFlags flags)
     : QMainWindow(parent, flags),
@@ -912,3 +914,5 @@ void GUIPlayer::wrkEndOfFile()
     appendWRKEvent(m_tick, ev);
 //    qDebug() << Q_FUNC_INFO;
 }
+
+DISABLE_WARNING_POP
