@@ -1,6 +1,6 @@
 /*
     Standard MIDI File player program
-    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,6 +28,9 @@
 #include <csignal>
 #include <drumstick/sequencererror.h>
 
+DISABLE_WARNING_PUSH
+DISABLE_WARNING_DEPRECATED_DECLARATIONS
+
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
 #define right Qt::right
 #define left Qt::left
@@ -378,3 +381,5 @@ int main(int argc, char **argv)
     delete player;
     return 0;
 }
+
+DISABLE_WARNING_POP
