@@ -1,10 +1,10 @@
 /*
     Virtual Piano test using the MIDI Sequencer C++ library 
-    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -26,40 +26,35 @@
 #include <drumstick/rtmidioutput.h>
 #include "ui_connections.h"
 
-using namespace drumstick::rt;
-
 class Connections : public QDialog
 {
     Q_OBJECT
 
 public:
-    Connections(QWidget *parent = 0);
-    void setInput(MIDIInput *in) { m_midiIn = in; }
-    void setOutput(MIDIOutput *out) { m_midiOut = out; }
-    void setInputs(QList<MIDIInput *> ins);
-    void setOutputs(QList<MIDIOutput *> outs);
-    MIDIInput *getInput() { return m_midiIn; }
-    MIDIOutput *getOutput() { return m_midiOut; }
-    void setAdvanced(bool value);
-    bool advanced();
-    bool midiThru();
+    explicit Connections(QWidget *parent = nullptr);
+    void setInput(drumstick::rt::MIDIInput *in);
+    void setOutput(drumstick::rt::MIDIOutput *out);
+    void setInputs(QList<drumstick::rt::MIDIInput *> ins);
+    void setOutputs(QList<drumstick::rt::MIDIOutput *> outs);
+    drumstick::rt::MIDIInput *getInput();
+    drumstick::rt::MIDIOutput *getOutput();
 
 public slots:
     void configureInputDriver();
     void configureOutputDriver();
     void clickedAdvanced(bool value);
-    void setMidiThru(bool value);
-    void refreshInputs(QString id);
-    void refreshOutputs(QString id);
+    void refreshInputs(int index);
+    void refreshOutputs(int index);
     void refresh();
-    void accept();
+    void reopenDrivers();
+    void accept() override;
+    void reject() override;
 
 private:
-    bool m_advanced;
-    bool m_thru;
     bool m_settingsChanged;
-    MIDIInput* m_midiIn;
-    MIDIOutput* m_midiOut;
+    drumstick::rt::MIDIInput *m_midiIn, *m_savedIn;
+    drumstick::rt::MIDIOutput *m_midiOut, *m_savedOut;
+    drumstick::rt::MIDIConnection m_connIn, m_connOut;
     Ui::ConnectionsClass ui;
 };
 
