@@ -27,7 +27,7 @@ p, li { white-space: pre-wrap; }
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-weight:600;&quot;&gt;Using Qt version: %QT_VERSION%&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Sample application for the &lt;/span&gt;&lt;a href=&quot;http://drumstick.sourceforge.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Drumstick MIDI Sequencer C++ library&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2021, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2022, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
@@ -43,7 +43,7 @@ p, li { white-space: pre-wrap; }
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-weight:600;&quot;&gt;Using Qt version: %QT_VERSION%&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:&apos;Sans Serif&apos;; font-size:9pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Sample application for the &lt;/span&gt;&lt;a href=&quot;http://drumstick.sourceforge.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Drumstick MIDI Sequencer C++ library&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2021, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2006-2022, Pedro Lopez-Cabanillas &amp;lt;&lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;plcl@users.sf.net&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;&amp;gt;&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt;This program is free software; you can redistribute it and/or modify  it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
 &lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; font-size:8pt;&quot;&gt; &lt;/span&gt;&lt;/p&gt;
@@ -197,25 +197,30 @@ p, li { white-space: pre-wrap; }
         <translation>si</translation>
     </message>
 </context>
+<context>
+    <name>QCoreApplication</name>
+    <message>
+        <source>Portable settings mode</source>
+        <translation type="vanished">Modo de ajustes portables</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="vpianomain.cpp" line="29"/>
         <source>Drumstick Simple Virtual Piano
-Copyright (C) 2006-2021 Pedro López-Cabanillas
+Copyright (C) 2006-2022 Pedro López-Cabanillas
 This program comes with ABSOLUTELY NO WARRANTY;
 This is free software, and you are welcome to redistribute it
 under certain conditions; see the LICENSE file for details.</source>
-        <translation>Drumstick Piano Virtual Sencillo
-Copyright (C) 2006-2021 Pedro López-Cabanillas
+        <translation type="vanished">Drumstick Piano Virtual Sencillo
+Copyright (C) 2006-2022 Pedro López-Cabanillas
 Este programa se ofrece SIN GARANTÍA ALGUNA.
 Este programa es software libre, y usted puede
 redistribuirlo bajo ciertas condiciones.</translation>
     </message>
     <message>
-        <location filename="vpianomain.cpp" line="113"/>
         <source>Portable settings mode</source>
-        <translation>Modo de ajustes portables</translation>
+        <translation type="vanished">Modo de ajustes portables</translation>
     </message>
 </context>
 <context>
@@ -226,165 +231,170 @@ redistribuirlo bajo ciertas condiciones.</translation>
         <translation>Piano virtual Drumstick</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="34"/>
+        <location filename="vpiano.ui" line="38"/>
         <source>File</source>
         <translation>Archivo</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="40"/>
+        <location filename="vpiano.ui" line="44"/>
         <source>Edit</source>
         <translation>Edición</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="47"/>
+        <location filename="vpiano.ui" line="51"/>
         <source>Help</source>
         <translation>Ayuda</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="54"/>
+        <location filename="vpiano.ui" line="58"/>
         <source>View</source>
         <translation>Ver</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="58"/>
+        <location filename="vpiano.ui" line="62"/>
         <source>Show Note Names</source>
         <translation>Mostrar nombres de notas</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="67"/>
+        <location filename="vpiano.ui" line="71"/>
         <source>Black Keys Names</source>
         <translation>Nombres de las teclas negras</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="75"/>
+        <location filename="vpiano.ui" line="79"/>
         <source>Names Orientation</source>
         <translation>Orientación de los nombres</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="83"/>
+        <location filename="vpiano.ui" line="87"/>
         <source>Central Octave Name</source>
         <translation>Nombre de la octava central</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="92"/>
+        <location filename="vpiano.ui" line="96"/>
         <source>Note Names</source>
         <translation>Nombres de notas</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="117"/>
+        <location filename="vpiano.ui" line="122"/>
         <source>&amp;Exit</source>
         <translation>&amp;Salir</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="122"/>
+        <location filename="vpiano.ui" line="127"/>
         <source>&amp;Preferences</source>
         <translation>&amp;Preferencias</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="127"/>
+        <location filename="vpiano.ui" line="132"/>
         <source>&amp;Connections</source>
         <translation>&amp;Conexiones</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="132"/>
+        <location filename="vpiano.ui" line="137"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="137"/>
+        <location filename="vpiano.ui" line="142"/>
         <source>About Qt</source>
         <translation>Acerca de Qt</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="148"/>
+        <location filename="vpiano.ui" line="153"/>
         <source>Never</source>
         <translation>Nunca</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="156"/>
+        <location filename="vpiano.ui" line="161"/>
         <source>When Activated</source>
         <translation>Cuando se activen</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="164"/>
+        <location filename="vpiano.ui" line="169"/>
         <source>Always</source>
         <translation>Siempre</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="175"/>
+        <location filename="vpiano.ui" line="180"/>
         <source>Sharps</source>
         <translation>Sostenidos</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="186"/>
+        <location filename="vpiano.ui" line="191"/>
         <source>Flats</source>
         <translation>Bemoles</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="194"/>
+        <location filename="vpiano.ui" line="199"/>
         <source>Nothing</source>
         <translation>Nada</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="205"/>
+        <location filename="vpiano.ui" line="210"/>
         <source>Horizontal</source>
         <translation>Horizontal</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="213"/>
+        <location filename="vpiano.ui" line="218"/>
         <source>Vertical</source>
         <translation>Vertical</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="221"/>
+        <location filename="vpiano.ui" line="226"/>
         <source>Automatic</source>
         <translation>Automática</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="226"/>
+        <location filename="vpiano.ui" line="231"/>
         <source>Names Font</source>
         <translation>Fuente para  nombres</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="234"/>
+        <location filename="vpiano.ui" line="239"/>
         <source>Minimal</source>
         <translation>Mínimo</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="242"/>
+        <location filename="vpiano.ui" line="247"/>
         <source>C3</source>
         <translation>do3</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="253"/>
+        <location filename="vpiano.ui" line="258"/>
         <source>C4</source>
         <translation>do4</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="261"/>
+        <location filename="vpiano.ui" line="266"/>
         <source>C5</source>
         <translation>do5</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="272"/>
+        <location filename="vpiano.ui" line="277"/>
         <source>Standard</source>
         <translation>Estándar</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="280"/>
+        <location filename="vpiano.ui" line="285"/>
         <source>Custom with Sharps</source>
         <translation>Personalizadas con sostenidos</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="288"/>
+        <location filename="vpiano.ui" line="293"/>
         <source>Custom with Flats</source>
         <translation>Personalizadas con bemoles</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="296"/>
+        <location filename="vpiano.ui" line="301"/>
         <source>C</source>
         <translation>do</translation>
     </message>
+    <message>
+        <location filename="vpiano.ui" line="309"/>
+        <source>Inverted Keys Color</source>
+        <translation>Teclas de color invertido</translation>
+    </message>
     <message>
         <location filename="vpiano.cpp" line="461"/>
         <source>Font to display note names</source>
@@ -401,4 +411,44 @@ redistribuirlo bajo ciertas condiciones.</translation>
         <translation>Nombres:</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Drumstick Simple Virtual Piano
+Copyright (C) 2006-2022 Pedro Lopez-Cabanillas
+This program comes with ABSOLUTELY NO WARRANTY;
+This is free software, and you are welcome to redistribute it
+under certain conditions; see the LICENSE file for details.</source>
+        <oldsource>Drumstick Simple Virtual Piano
+Copyright (C) 2006-2022 Pedro López-Cabanillas
+This program comes with ABSOLUTELY NO WARRANTY;
+This is free software, and you are welcome to redistribute it
+under certain conditions; see the LICENSE file for details.</oldsource>
+        <translation type="vanished">Drumstick Piano Virtual Sencillo
+Copyright (C) 2006-2022 Pedro Lopez-Cabanillas
+Este programa se ofrece SIN GARANTÍA ALGUNA.
+Este programa es software libre, y usted puede
+redistribuirlo bajo ciertas condiciones; vea el archivo
+LICENSE para detalles.</translation>
+    </message>
+    <message>
+        <location filename="vpianomain.cpp" line="28"/>
+        <source>Drumstick Simple Virtual Piano
+Copyright (C) 2006-2022 Pedro Lopez-Cabanillas
+This program comes with ABSOLUTELY NO WARRANTY; This is free software, and you are welcome to redistribute it under certain conditions; see the LICENSE file for details.</source>
+        <translation>Drumstick Piano Virtual Sencillo
+Copyright (C) 2006-2022 Pedro Lopez-Cabanillas
+Este programa se ofrece SIN GARANTÍA ALGUNA. Este programa es software libre, y usted puede redistribuirlo bajo ciertas condiciones; vea el archivo LICENSE para detalles.</translation>
+    </message>
+    <message>
+        <location filename="vpianomain.cpp" line="124"/>
+        <source>Portable settings mode</source>
+        <translation>Modo de ajustes portables</translation>
+    </message>
+    <message>
+        <location filename="vpianomain.cpp" line="138"/>
+        <source>Fatal error from a MIDI backend.</source>
+        <translation>Error grave en el soporte MIDI.</translation>
+    </message>
+</context>
 </TS>
