@@ -1,6 +1,6 @@
 /*
     Virtual Piano test using the MIDI Sequencer C++ library
-    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -77,6 +77,7 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags)
     connect(ui.actionConnections, &QAction::triggered, this,  &VPiano::slotConnections);
     connect(ui.actionPreferences, &QAction::triggered, this,  &VPiano::slotPreferences);
     connect(ui.actionNames_Font, &QAction::triggered, this, &VPiano::slotChangeFont);
+    connect(ui.actionInverted_Keys_Color, &QAction::triggered, this, &VPiano::slotInvertedColors);
 
     QActionGroup* nameGroup = new QActionGroup(this);
     nameGroup->setExclusive(true);
@@ -154,7 +155,7 @@ void VPiano::initialize()
                 this, QOverload<int,int,int>::of(&VPiano::slotNoteOff),
                 Qt::QueuedConnection);
 
-        if (!VPianoSettings::instance()->lastInputConnection().isEmpty()) {
+        if (m_midiIn != nullptr) {
             m_midiIn->initialize(settings.getQSettings());
             MIDIConnection conn;
             auto conin = m_midiIn->connections(VPianoSettings::instance()->advanced());
@@ -413,18 +414,17 @@ void VPiano::readSettings()
     ui.pianokeybd->setBaseOctave(VPianoSettings::instance()->baseOctave());
     ui.pianokeybd->setNumKeys(VPianoSettings::instance()->numKeys(), VPianoSettings::instance()->startingKey());
 
-    ui.pianokeybd->setKeyPressedColor(Qt::red);
     /*
      * PianoKeybd::setKeyPressedColor(red) is equivalent to:
      *   PianoPalette hpalette(PAL_SINGLE);
      *   hpalette.setColor(0, Qt::red);
      *   ui.pianokeybd->setHighlightPalette(hpalette);
      */
-    PianoPalette bgpalette(PAL_KEYS);
-    bgpalette.setColor(0, QColor("ivory"));
-    bgpalette.setColor(1, QColor(0x40,0x10,0x10));
-    ui.pianokeybd->setBackgroundPalette(bgpalette);
+    ui.pianokeybd->setKeyPressedColor(Qt::red);
     ui.pianokeybd->setVelocityTint(false);
+
+    ui.actionInverted_Keys_Color->setChecked(VPianoSettings::instance()->invertedKeys());
+    slotInvertedColors(ui.actionInverted_Keys_Color->isChecked());
 }
 
 void VPiano::setPortableConfig(const QString fileName)
@@ -559,3 +559,29 @@ void VPiano::slotNoteName(const QString& name)
         ui.statusBar->showMessage(name);
     }
 }
+
+void VPiano::slotInvertedColors(bool checked)
+{
+    PianoPalette bgpal(PAL_KEYS);
+    PianoPalette fpal(PAL_FONT);
+    if (checked) {
+        bgpal.setColor(0, Qt::black);
+        bgpal.setColor(1, Qt::white);
+
+        fpal.setColor(0, Qt::white);
+        fpal.setColor(1, Qt::black);
+        fpal.setColor(2, Qt::white);
+        fpal.setColor(3, Qt::white);
+    } else {
+        bgpal.setColor(0, QColor("ivory"));
+        bgpal.setColor(1, QColor(0x40,0x10,0x10));
+
+        fpal.setColor(0, Qt::black);
+        fpal.setColor(1, Qt::white);
+        fpal.setColor(2, Qt::white);
+        fpal.setColor(3, Qt::white);
+    }
+    ui.pianokeybd->setBackgroundPalette(bgpal);
+    ui.pianokeybd->setForegroundPalette(fpal);
+    VPianoSettings::instance()->setInvertedKeys(checked);
+}
